# estival
Calibration and optimization tools for summer2
https://github.com/monash-emu/summer2

Estival provides a simple API for using summer2 CompartmentalModels with a variety of optimization frameworks, including
- pymc
- nevergrad

### CHANGELOG

- 0.2.2  
Add logprior/logposterior to BayesianCompartmentalModel
- 0.2.3  
Include tensorflow-probability(jax) for more (and better tested) stats modules